@@ -1,6 +1,6 @@
 package Treex::Block::Read::BaseReader;
-BEGIN {
-  $Treex::Block::Read::BaseReader::VERSION = '0.06571';
+{
+  $Treex::Block::Read::BaseReader::VERSION = '0.07190';
 }
 use Moose;
 use Treex::Core::Common;
@@ -13,26 +13,23 @@ sub next_document {
     return log_fatal "method next_document must be overriden in " . ref($self);
 }
 
-has selector => ( isa => 'Selector', is => 'ro', default => q{} );
+has selector => ( isa => 'Treex::Type::Selector', is => 'ro', default => q{} );
+
+# Note that "language" is intentionally not required here,
+# because some derived classes (e.g. Read::Treex) do not need it.
+# However, if a derived class reads a format where the language is not specified,
+# it must add the parameter language using:
+#has language => ( isa => 'Treex::Type::LangCode', is => 'ro', required=>1 );
 
-has filenames => (
-    isa           => 'ArrayRef[Str]',
-    is            => 'ro',
-    lazy_build    => 1,
-    documentation => 'array of filenames to be loaded;'
-        . ' automatically initialized from the attributes "from" and "filelist"',
-);
 
 has from => (
-    isa           => 'Str',
+    isa           => 'Treex::Core::Files',
     is            => 'ro',
-    documentation => 'space or comma separated list of filenames to be loaded',
-);
-
-has filelist => (
-    isa           => 'Str',
-    is            => 'ro',
-    documentation => 'a file that contains the list of filenames to be loaded, one per line',
+    coerce        => 1,
+    handles       => [qw(current_filename file_number _set_file_number)],
+    documentation => 'arrayref of filenames to be loaded, '
+        . 'coerced from a space or comma separated list of filenames, '
+        . 'see POD for details',
 );
 
 has file_stem => (
@@ -41,15 +38,6 @@ has file_stem => (
     documentation => 'how to name the loaded documents',
 );
 
-has file_number => (
-    isa           => 'Int',
-    is            => 'ro',
-    writer        => '_set_file_number',
-    default       => 0,
-    init_arg      => undef,
-    documentation => 'Number of input files loaded so far.',
-);
-
 has is_one_doc_per_file => (
     is      => 'rw',
     isa     => 'Bool',
@@ -58,41 +46,6 @@ has is_one_doc_per_file => (
 
 has _file_numbers => ( is => 'rw', default => sub { {} } );
 
-sub _build_filenames {
-    my $self = shift;
-
-    log_fatal "Parameters 'from' or 'filelist' must be defined!" if !defined $self->from && !defined $self->filelist;
-
-    my $filenames = [];
-
-    # add all files in the 'from' parameter to the list (avoid adding STDIN if filelist is set)
-    if ( $self->from && ( !$self->filelist || $self->from ne q{-} ) ) {
-        push @{$filenames}, split( /[ ,]+/, $self->from );
-    }
-
-    # add all files from the filelist to the list
-    if ( $self->filelist ) {
-        my @list = read_file( $self->filelist );
-        log_fatal 'File list ' . $self->filelist . ' cannot be loaded!' if @list == 1 && !defined( $list[0] );
-        my @trimmed;
-        foreach my $item (@list) {
-            $item =~ s/\s*\r?\n$//;
-            $item =~ s/^\s*//;
-            push @trimmed, $item; # remove EOL chars, trim
-        }
-        push @{$filenames}, @trimmed;
-    }
-
-    # return the resulting list
-    return $filenames;
-}
-
-sub current_filename {
-    my ($self) = @_;
-    return if $self->file_number == 0 || $self->file_number > @{ $self->filenames };
-    return $self->filenames->[ $self->file_number - 1 ];
-}
-
 sub is_next_document_for_this_job {
     my ($self) = @_;
     return 1 if !$self->jobindex;
@@ -145,12 +98,18 @@ sub new_document {
     }
 
     $self->_set_doc_number( $self->doc_number + 1 );
-    return Treex::Core::Document->new( \%args );
+
+    my $document = Treex::Core::Document->new( \%args );
+    if ( defined $load_from && $load_from =~ /\.gz$/ ) {
+        $document->set_compress(1);
+    }
+
+    return $document;
 }
 
 sub number_of_documents {
     my $self = shift;
-    return $self->is_one_doc_per_file ? scalar @{ $self->filenames } : undef;
+    return $self->is_one_doc_per_file ? $self->from->number_of_files : undef;
 }
 
 after 'restart' => sub {
@@ -168,7 +127,7 @@ Treex::Block::Read::BaseReader - abstract ancestor for document readers
 
 =head1 VERSION
 
-version 0.06571
+version 0.07190
 
 =head1 DESCRIPTION
 
@@ -260,4 +219,4 @@ Martin Popel
 
 Copyright © 2011 by Institute of Formal and Applied Linguistics, Charles University in Prague
 
-This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
\ No newline at end of file
+This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
