@@ -1,6 +1,6 @@
 package Treex::Block::Write::Treex;
-BEGIN {
-  $Treex::Block::Write::Treex::VERSION = '0.06571';
+{
+  $Treex::Block::Write::Treex::VERSION = '0.07190';
 }
 use Moose;
 use Treex::Core::Common;
@@ -12,6 +12,12 @@ has [qw(file_stem path)] => (
     documentation => 'overrides the respective attributes in documents (filled in by a DocumentReader)',
 );
 
+has stem_suffix => (
+    isa           => 'Str',
+    is            => 'ro',
+    documentation => 'a suffix to append after file_stem',
+);
+
 has to => (
     isa           => 'Str',
     is            => 'ro',
@@ -26,22 +32,48 @@ has filenames => (
         . ' automatically initialized from the attribute "to"',
 );
 
+has compress => (
+    is => 'rw',
+    isa => 'Bool',
+    default => undef,
+    documentation => 'compression to .gz. If $doc->compress is undef, default is 1',
+);
+
 sub _build_filenames {
     my $self = shift;
     log_fatal "Parameter 'to' must be defined!" if !defined $self->to;
     return [ split /[ ,]+/, $self->to ];
 }
 
+sub _extension {
+    my ( $self, $document ) = @_;
+    my $compress = 1;
+    if ( defined $self->compress ) {
+        $compress = $self->compress;
+    }
+    elsif ( defined $document->compress ) {
+        $compress = $document->compress;
+    }
+
+    return  '.treex' . ( $compress ? '.gz' : '' );
+}
+
 sub process_document {
     my ( $self, $document ) = @_;
-    my $filename = $document->full_filename . '.treex';
+    my $filename = $document->full_filename . $self->_extension($document);
     if ( defined $self->path ) {
         $document->set_path( $self->path );
-        $filename = $document->full_filename . '.treex';
+        $filename = $document->full_filename . $self->_extension($document);;
     }
     if ( defined $self->file_stem ) {
         $document->set_file_stem( $self->file_stem );
-        $filename = $document->full_filename . '.treex';
+        $filename = $document->full_filename . $self->_extension($document);;
+    }
+    if ( defined $self->stem_suffix ) {
+        my $origstem = defined $self->file_stem
+                       ? $self->file_stem : $document->file_stem;
+        $document->set_file_stem( $origstem . $self->stem_suffix );
+        $filename = $document->full_filename . $self->_extension($document);;
     }
     if ( defined $self->to ) {
         my ( $next_filename, @rest_filenames ) = @{ $self->filenames };
@@ -51,6 +83,12 @@ sub process_document {
         }
         else {
             $filename = ( defined $self->path ? $self->path : '' ) . $next_filename;
+            
+            # HACK: Treex::PML::Document->save() cannot take filehandle
+            if ($filename eq '-'){
+                $filename = '/dev/stdout';
+            }
+            
             $self->set_filenames( \@rest_filenames );
         }
     }
@@ -69,7 +107,7 @@ Treex::Block::Write::Treex
 
 =head1 VERSION
 
-version 0.06571
+version 0.07190
 
 =head1 DESCRIPTION
 
@@ -91,6 +129,10 @@ overrides the respective attributes in documents
 (filled in by a L<DocumentReader|Treex::Core::DocumentReader>),
 which are used for generating output file names
 
+=item stem_suffix
+
+a string to append after file_stem
+
 =back
 
 =head1 METHODS
@@ -111,4 +153,4 @@ Martin Popel
 
 Copyright © 2011 by Institute of Formal and Applied Linguistics, Charles University in Prague
 
-This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
\ No newline at end of file
+This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
