@@ -1,7 +1,9 @@
 package Treex::Core;
-BEGIN {
-  $Treex::Core::VERSION = '0.06571';
+{
+  $Treex::Core::VERSION = '0.07190';
 }
+use strict;
+use warnings;
 use Treex::Core::Document;
 use Treex::Core::Node;
 use Treex::Core::Bundle;
@@ -21,7 +23,7 @@ Treex::Core - interface to linguistic structures and processing units in Treex
 
 =head1 VERSION
 
-version 0.06571
+version 0.07190
 
 =head1 SYNOPSIS
 
@@ -190,4 +192,4 @@ David Mareček <marecek@ufal.mff.cuni.cz>
 
 Copyright © 2011 by Institute of Formal and Applied Linguistics, Charles University in Prague
 
-This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
\ No newline at end of file
+This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
