@@ -1,8 +1,9 @@
 package Treex::Core::Common;
-BEGIN {
-  $Treex::Core::Common::VERSION = '0.06571';
+{
+  $Treex::Core::Common::VERSION = '0.07190';
 }
-use Moose;
+use strict;
+use warnings;
 use 5.008;
 
 use utf8;
@@ -12,6 +13,8 @@ use MooseX::SemiAffordanceAccessor::Role::Attribute;
 use Treex::Core::Log;
 use Treex::Core::Config;
 use Treex::Core::Resource;
+use Treex::Core::Types;
+use Treex::Core::Files;
 use List::MoreUtils;
 use List::Util;
 use Scalar::Util;
@@ -36,7 +39,7 @@ sub pos_validated_list {
     return @{$args_ref};
 }
 
-# Choose which variant to use according to Treex::Core::Config::$params_validate
+# Choose which variant to use according to $Treex::Core::Config::params_validate
 if ( $Treex::Core::Config::params_validate == 2 ) {    ## no critic (ProhibitPackageVars)
     require MooseX::Params::Validate;
     $validation_sub = \&MooseX::Params::Validate::pos_validated_list;
@@ -48,7 +51,6 @@ else {
 my ( $import, $unimport, $init_meta ) =
     Moose::Exporter->build_import_methods(
     install         => [qw(unimport init_meta)],
-    also            => 'Moose',
     class_metaroles => { attribute => ['MooseX::SemiAffordanceAccessor::Role::Attribute'] },
     as_is           => [
         \&Treex::Core::Log::log_fatal,
@@ -56,6 +58,9 @@ my ( $import, $unimport, $init_meta ) =
         \&Treex::Core::Log::log_debug,
         \&Treex::Core::Log::log_set_error_level,
         \&Treex::Core::Log::log_info,
+        \&Treex::Core::Types::get_lang_name,
+        \&Treex::Core::Types::is_lang_code,
+        \&Treex::Core::Resource::require_file_from_share,
         \&List::MoreUtils::first_index,
         \&List::MoreUtils::all,
         \&List::MoreUtils::any,
@@ -73,68 +78,6 @@ sub import {
     goto &$import;
 }
 
-subtype 'Selector'
-    => as 'Str'
-    => where {m/^[a-z\d]*$/i}
-=> message {"Selector must =~ /^[a-z\\d]*\$/i. You've provided $_"};    #TODO: this messege is not printed
-
-subtype 'Layer'
-    => as 'Str'
-    => where {m/^[ptan]$/i}
-=> message {"Layer must be one of: [P]hrase structure, [T]ectogrammatical, [A]nalytical, [N]amed entities, you've provided $_"};
-
-subtype 'Message'                                                       #nonempty string
-    => as 'Str'
-    => where { $_ ne '' }
-=> message {"Message must be nonempty"};
-
-#preparation for possible future constraints
-subtype 'Id'
-    => as 'Str';
-
-# TODO: Should this be named ZoneCode or ZoneLabel?
-subtype 'ZoneCode'
-    => as 'Str'
-    => where { my ( $l, $s ) = split /_/, $_; is_lang_code($l) && ( !defined $s || $s =~ /^[a-z\d]*$/i ) }
-=> message {'ZoneCode must be LangCode or LangCode_Selector, e.g. "en_src"'};
-
-# ISO 639-1 language code with some extensions from ISO 639-2
-# Added code for Modern Greek which comes under ISO 639-3
-use Locale::Language;
-my %EXTRA_LANG_CODES = (
-    'bxr'     => "Buryat",
-    'dsb'     => "Lower Sorbian",
-    'ell'     => "ISO 639-3 code for Modern Greek",
-    'grc'     => "ISO 639-2 code for Ancient Greek",
-    'hsb'     => "Upper Sorbian",
-    'hak'     => "Hakka",
-    'kaa'     => "Karakalpak",
-    'ku-latn' => "Kurdish in Latin script",
-    'ku-arab' => "Kurdish in Arabic script",
-    'ku-cyrl' => "Kurdish in Cyrillic script",
-    'nan'     => "Taiwanese",
-    'rmy'     => "Romany",
-    'sah'     => "Yakut",
-    'und'     => "ISO 639-2 code for undetermined/unknown language",
-    'xal'     => "Kalmyk",
-    'yue'     => "Cantonese",
-    'mul'     => "ISO 639-2 code for multiple languages",
-);
-
-my %IS_LANG_CODE = map { $_ => 1 } ( all_language_codes(), keys %EXTRA_LANG_CODES );
-
-#enum 'LangCode' => keys %IS_LANG_CODE;
-subtype 'LangCode'
-    => as 'Str'
-    => where { defined $IS_LANG_CODE{$_} }
-=> message {'LangCode must be valid ISO 639-1 code. E.g. en, de, cs'};
-sub is_lang_code { return $IS_LANG_CODE{ $_[0] }; }
-
-sub get_lang_name {
-    my $code = shift;
-    return exists $EXTRA_LANG_CODES{$code} ? $EXTRA_LANG_CODES{$code} : code2language($code);
-}
-
 1;
 
 __END__
@@ -147,7 +90,7 @@ Treex::Core::Common - shorten the "C<use>" part of your Perl codes
 
 =head1 VERSION
 
-version 0.06571
+version 0.07190
 
 =head1 SYNOPSIS
 
@@ -160,13 +103,14 @@ Instead of
  use utf8;
  use strict;
  use warnings;
- use Moose;
  use Moose::Util::TypeConstraints qw(enum);
  use MooseX::SemiAffordanceAccessor;
  use MooseX::Params::Validate qw(pos_validated_list);
  use Treex::Core::Log;
  use Treex::Core::Config;
  use Treex::Core::Resource;
+ use Treex::Core::Types;
+ use Treex::Core::Files;
  use List::MoreUtils qw(all any first_index);
  use List::Util qw(first);
  use Scalar::Util qw(weaken);
@@ -200,4 +144,4 @@ Martin Popel <popel@ufal.mff.cuni.cz>
 
 Copyright © 2011 by Institute of Formal and Applied Linguistics, Charles University in Prague
 
-This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
\ No newline at end of file
+This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
