@@ -1,9 +1,9 @@
 package Treex::Core::Files;
 {
-  $Treex::Core::Files::VERSION = '0.08633_1';
+  $Treex::Core::Files::VERSION = '0.07190';
 }
 use Moose;
-use MooseX::SemiAffordanceAccessor 0.09;
+use MooseX::SemiAffordanceAccessor;
 use Treex::Core::Log;
 use autodie;
 use File::Slurp 9999.19;
@@ -79,11 +79,11 @@ __END__
 
 =head1 NAME
 
-Treex::Core::Files - helper class for iterating over filenames
+Treex::Core::Files - helper class for iterating over filenames 
 
 =head1 VERSION
 
-version 0.08633_1
+version 0.07190
 
 =head1 SYNOPSIS
 
