@@ -1,6 +1,6 @@
 package Treex::Core::Node::A;
-BEGIN {
-  $Treex::Core::Node::A::VERSION = '0.06571';
+{
+  $Treex::Core::Node::A::VERSION = '0.07190';
 }
 use Moose;
 use Treex::Core::Common;
@@ -174,6 +174,11 @@ sub copy_atree
 {
     my $self      = shift;
     my $target    = shift;
+
+    # TODO probably we should do deepcopy
+    my %copy_of_wild = %{$self->wild};
+    $target->set_wild(\%copy_of_wild);
+
     my @children0 = $self->get_children( { ordered => 1 } );
     foreach my $child0 (@children0)
     {
@@ -182,19 +187,24 @@ sub copy_atree
         my $child1 = $target->create_child();
 
         # We should copy all attributes that the node has but it is not easy to figure out which these are.
-        # As a workaround, we list the attributes here directly.
+        # TODO: As a workaround, we list the attributes here directly.
         foreach my $attribute (
             'form', 'lemma', 'tag', 'no_space_after', 'ord', 'afun', 'is_member', 'is_parenthesis_root',
-            'conll/deprel', 'conll/cpos', 'conll/pos', 'conll/feat'
+            'conll/deprel', 'conll/cpos', 'conll/pos', 'conll/feat', 'is_shared_modifier',
             )
         {
             my $value = $child0->get_attr($attribute);
             $child1->set_attr( $attribute, $value );
         }
 
+        # TODO probably we should do deepcopy
+        my %copy_of_wild = %{$child0->wild};
+        $child1->set_wild(\%copy_of_wild);
+
         # Call recursively on the subtrees of the children.
         $child0->copy_atree($child1);
     }
+
     return;
 }
 
@@ -335,7 +345,7 @@ Treex::Core::Node::A
 
 =head1 VERSION
 
-version 0.06571
+version 0.07190
 
 =head1 DESCRIPTION
 
@@ -433,4 +443,4 @@ Martin Popel <popel@ufal.mff.cuni.cz>
 
 Copyright © 2011 by Institute of Formal and Applied Linguistics, Charles University in Prague
 
-This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
\ No newline at end of file
+This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
