@@ -1,6 +1,6 @@
 package Treex::Core::Node::P;
-BEGIN {
-  $Treex::Core::Node::P::VERSION = '0.06571';
+{
+  $Treex::Core::Node::P::VERSION = '0.07190';
 }
 use Moose;
 use Treex::Core::Common;
@@ -39,6 +39,11 @@ override 'get_ordering_value' => sub {
     return;
 };
 
+sub is_terminal {
+  my $self = shift @_;
+  return $self->get_pml_type_name eq 'p-terminal.type' ? 1 : 0;
+}
+
 sub create_nonterminal_child {
     my $self    = shift @_;
     my $fs_file = $self->get_bundle->get_document()->_pmldoc;
@@ -175,7 +180,7 @@ Treex::Core::Node::P
 
 =head1 VERSION
 
-version 0.06571
+version 0.07190
 
 =head1 DESCRIPTION
 
@@ -191,4 +196,4 @@ Zdenek Zabokrtsky <zabokrtsky@ufal.mff.cuni.cz>
 
 Copyright © 2011 by Institute of Formal and Applied Linguistics, Charles University in Prague
 
-This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
\ No newline at end of file
+This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
