@@ -1,6 +1,6 @@
 package Treex::Core::TredView;
-BEGIN {
-  $Treex::Core::TredView::VERSION = '0.06571';
+{
+  $Treex::Core::TredView::VERSION = '0.07190';
 }
 
 # planned to be used from contrib.mac of tred's extensions
@@ -11,6 +11,7 @@ use Treex::Core::TredView::TreeLayout;
 use Treex::Core::TredView::Labels;
 use Treex::Core::TredView::Styles;
 use Treex::Core::TredView::Vallex;
+use Treex::Core::Types;
 use List::Util qw(first);
 
 has 'grp'       => ( is => 'rw' );
@@ -47,7 +48,24 @@ has fast_loading => (
     documentation => 'Do the precomputation lazily for each bundle',
 );
 
+has _displayed_nodes => (
+    is => 'rw',
+    isa => 'HashRef[Treex::Core::Node]',
+    default => sub { {} }
+);
+has _ptb_index_map => (
+    is => 'rw',
+    isa => 'HashRef[Treex::Core::Node::P]',
+    default => sub { {} }
+);
+has _ptb_coindex_map => (
+    is => 'rw',
+    isa => 'HashRef[Treex::Core::Node::P]',
+    default => sub { {} }
+);
+
 has 'clause_collapsing' => ( is => 'rw', isa => 'Bool', default => 0 );
+has 'show_alignment'    => ( is => 'rw', isa => 'Bool', default => 1 );
 
 sub _spread_nodes {
     my ( $self, $node ) = @_;
@@ -64,7 +82,7 @@ sub _spread_nodes {
         push @lower, @buf;
     }
     $right += $pos;
-    return ( 0, $node ) if ! @lower;
+    return ( 0, $node ) if !@lower;
 
     my $mid;
     if ( scalar( $node->children ) == 1 ) {
@@ -88,13 +106,20 @@ sub get_nodelist_hook {
                                              # results in Can't locate object method "get_all_zones" via package "Treex::PML::Node" at /ha/work/people/popel/tectomt/treex/lib/Treex/Core/TredView.pm line 22
 
     my $layout = $self->tree_layout->get_layout();
+    $self->{'_ptb_index_map'} = {};
+    $self->{'_ptb_coindex_map'} = {};
     my %nodes;
 
     foreach my $tree ( map { $_->get_all_trees } $bundle->get_all_zones ) {
         my $label = $self->tree_layout->get_tree_label($tree);
         my @nodes;
         if ( $tree->get_layer eq 'p' ) {
-            ( my $foo, @nodes ) = $self->_spread_nodes($tree);
+            @nodes = $self->_spread_nodes($tree);
+            shift @nodes;
+            foreach my $node (@nodes) {
+                $self->{'_ptb_index_map'}->{$node->{'index'}} = $node if defined $node->{'index'};
+                $self->{'_ptb_coindex_map'}->{$node->{'coindex'}} = $node if defined $node->{'coindex'};
+            }
         }
         elsif ( $tree->does('Treex::Core::Node::Ordered') ) {
             @nodes = $tree->get_descendants( { add_self => 1, ordered => 1 } );
@@ -126,8 +151,8 @@ sub get_nodelist_hook {
     for ( my $col = 0; $col < scalar @$layout; $col++ ) {
         my @task = ();
         for ( my $row = 0; $row < scalar @{ $layout->[$col] }; $row++ ) {
-            if ( $layout->[$col][$row] ) {
-                my $label     = $layout->[$col][$row];
+            if ( $layout->[$col][$row] and $layout->[$col][$row]->{'visible'} ) {
+                my $label     = $layout->[$col][$row]->{'label'};
                 my %tree_info = ();
                 $tree_info{'total'} = $tree_info{'left'} = scalar @{ $nodes{$label} };
                 $tree_info{'label'} = $label;
@@ -169,6 +194,8 @@ sub get_nodelist_hook {
         }
     }
 
+    $self->{'_displayed_nodes'} = { map { $_->attr('id') => 1 } @nodes };
+
     unless ( $currentNode and ( first { $_ == $currentNode } @nodes ) ) {
         $currentNode = $nodes[0];
     }
@@ -229,6 +256,7 @@ sub value_line_doubleclick_hook {
 
     my $layout = $self->tree_layout->get_layout;
     my %ordering;
+    my %visible;
     my $i     = 0;
     my $row   = 0;
     my $found = 1;
@@ -236,18 +264,25 @@ sub value_line_doubleclick_hook {
     while ($found) {
         $found = 0;
         for ( my $col = 0; $col < scalar @$layout; $col++ ) {
-            if ( $layout->[$col][$row] ) {
-                $ordering{ $layout->[$col][$row] } = $i++;
+            if ( defined $layout->[$col][$row] ) {
+                if ($layout->[$col][$row]->{'visible'}) {
+                    $ordering{ $layout->[$col][$row]->{'label'} } = $i++;
+                    $visible{$layout->[$col][$row]->{'label'}} = 1;
+                }
                 $found = 1;
             }
         }
         $row++;
     }
-    my @trees = sort { $ordering{ $self->tree_layout->get_tree_label($a) } <=> $ordering{ $self->tree_layout->get_tree_label($b) } } $bundle->get_all_trees;
+    my @trees = sort {
+        $ordering{ $self->tree_layout->get_tree_label($a) } <=> $ordering{ $self->tree_layout->get_tree_label($b) }
+    } grep {
+      exists $visible{ $self->tree_layout->get_tree_label($_) }
+    } $bundle->get_all_trees;
 
     for my $tree (@trees) {
         for my $node ( $tree->get_descendants ) {
-            next if $node->get_layer eq 'p' and $node->get_pml_type_name =~ m/nonterminal/;
+            next if $node->get_layer eq 'p' and not $node->is_terminal;
             return $node if exists $tags{"$node"};
         }
     }
@@ -257,7 +292,7 @@ sub value_line_doubleclick_hook {
 
 # --------------- PRECOMPUTING VISUALIZATION (node labels, styles, coreference links, groups...) ---
 
-my @layers = qw(a t p n);
+my @layers = map {lc} Treex::Core::Types::layers();
 
 # To be run only once when the file is opened. Tree depths never change.
 sub precompute_tree_depths {
@@ -304,7 +339,8 @@ sub precompute_tree_shifts {
         my $max_depth = 0;
         @trees = ();
         for ( my $col = 0; $col < scalar @$layout; $col++ ) {
-            if ( my $label = $layout->[$col][$row] ) {
+            if ( defined $layout->[$col][$row] ) {
+                my $label = $layout->[$col][$row]->{'label'};
                 my $depth = $forest{$label}{_tree_depth};
                 push @trees, $label;
                 $max_depth = $depth if $depth > $max_depth;
@@ -373,8 +409,8 @@ sub get_clickable_sentence_for_a_zone {
     for my $anode (@anodes) {
         my $id = $anode->id;
         push @{ $refs{$id} }, $anode;
-        if ( $anode->attr('p/terminal.rf') ) {
-            my $pnode = $self->treex_doc->get_node_by_id( $anode->attr('p/terminal.rf') );
+        if ( $anode->attr('p_terminal.rf') ) {
+            my $pnode = $self->treex_doc->get_node_by_id( $anode->attr('p_terminal.rf') );
             push @{ $refs{$id} }, $pnode;
             while ( $pnode->parent ) {
                 $pnode = $pnode->parent;
@@ -385,7 +421,7 @@ sub get_clickable_sentence_for_a_zone {
 
     my @out;
     for my $anode (@anodes) {
-        push @out, [ $anode->form, @{ $refs{ $anode->id } || [] }, 'anode:' . $anode->id ];
+        push @out, [ $anode->form, @{ $refs{ $anode->id } || [] } ];
         if ( $anode->clause_number ) {
             my $clr = $self->_styles->_colors->get_clause_color( $anode->clause_number );
             push @{ $out[-1] }, "-foreground => $clr";
@@ -483,16 +519,14 @@ sub tnode_hint {
 
 sub nnode_hint {
     my ( $self, $node ) = @_;
-    return undef;
+    return;
 }
 
 sub pnode_hint {
     my ( $self, $node ) = @_;
-
     my @lines = ();
-    my $terminal = $node->get_pml_type_name eq 'p-terminal.type' ? 1 : 0;
 
-    if ($terminal) {
+    if ($node->is_terminal) {
         push @lines, map { "$_: " . ( defined $node->{$_} ? $node->{$_} : '' ) } qw(lemma tag form);
     }
     else {
@@ -524,11 +558,37 @@ sub node_style_hook {
         }
     }
 
+    # P-layer indexes and coindexes
+    if ($node->get_layer eq 'p') {
+        my $coindex;
+        if ($node->attr('form') and $node->attr('form') =~ m/-(\d+)$/) {
+            $coindex = $1;
+        } elsif ($node->attr('coindex')) {
+            $coindex = $node->attr('coindex');
+        }
+
+        if ($coindex) {
+            my $target_node;
+            if (exists $self->{'_ptb_index_map'}->{$coindex}) {
+              $target_node = $self->{'_ptb_index_map'}->{$coindex};
+            } elsif ($node->is_terminal and exists $self->{'_ptb_coindex_map'}->{$coindex}) {
+              $target_node = $self->{'_ptb_coindex_map'}->{$coindex};
+            }
+
+            if ($target_node) {
+              push @target_ids, $target_node->{'id'};
+              push @arrow_types, 'coindex';
+            }
+        }
+    }
+
     # alignment
-    if ( my $links = $node->attr('alignment') ) {
+    if ( $self->show_alignment and my $links = $node->attr('alignment') ) {
         foreach my $link (@$links) {
-            push @target_ids,  $link->{'counterpart.rf'};
-            push @arrow_types, 'alignment';
+            if (exists $self->_displayed_nodes->{$link->{'counterpart.rf'}}) {
+                push @target_ids,  $link->{'counterpart.rf'};
+                push @arrow_types, 'alignment';
+            }
         }
     }
 
@@ -626,6 +686,11 @@ sub toggle_clause_collapsing {
     }
 }
 
+sub toggle_alignment {
+    my $self = shift;
+    $self->show_alignment( not $self->show_alignment );
+}
+
 1;
 
 __END__
@@ -638,7 +703,7 @@ Treex::Core::TredView - visualization of Treex files in TrEd
 
 =head1 VERSION
 
-version 0.06571
+version 0.07190
 
 =head1 DESCRIPTION
 
@@ -700,4 +765,4 @@ Martin Popel <popel@ufal.mff.cuni.cz>
 
 Copyright © 2011 by Institute of Formal and Applied Linguistics, Charles University in Prague
 
-This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
\ No newline at end of file
+This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
